@@ -11,13 +11,13 @@ class QuickbooksCore(SitesCore):
     """
     Quickbooks object. Please Inheritance it.
     """
-    def get_otp_code(self) -> str:
+    def get_otp_code(self, code: str = '') -> str:
         """
         Please, modify this function in your code
         :return:
         """
 
-        return ''
+        return code
 
     def send_message_service_type_not_found(self, manager: str, customer_or_service: str) -> None:
         pass
